import { ViteSSG } from 'vite-ssg'
import { createPinia } from 'pinia'
import hljs from 'highlight.js'
import { marked } from 'marked'
import { markedHighlight } from 'marked-highlight'

import type { RoutedWindow } from '@goldenwere/mackenzii-types'
import { registerLinkEmbed } from '@goldenwere/mackenzii-embeds'

import main from './main.vue'
import './main.sass'

import { createRoutes, initializeRouteStore } from './routes'
import { headingSectionsExtension } from './utilities/marked'

declare const window: RoutedWindow

marked
.use(headingSectionsExtension() as any)
.use(markedHighlight({
  langPrefix: 'hljs language-',
  highlight(code, lang) {
    const language = hljs.getLanguage(lang) ? lang : 'plaintext'
    return hljs.highlight(code, { language }).value
  },
}))

export const createApp = ViteSSG(
  // the root component
  main,
  // vue-router options
  { routes: createRoutes() },
  // function to have custom setups
  ({ app, router, routes, isClient, initialState }) => {
    registerLinkEmbed()
    window.router = router
    app.use(createPinia())
    initializeRouteStore(routes)
  },
)
